==> angularx-semantic-ui-0.0.1.tgz: package/README.md <==
# angularx-semantic-ui
[![peerDependencies Status](https://david-dm.org/lon-yang/angularx-semantic-ui/peer-status.svg)](https://david-dm.org/lon-yang/angularx-semantic-ui?type=peer)
[![npm version](https://badge.fury.io/js/angularx-semantic-ui.svg)](https://badge.fury.io/js/angularx-semantic-ui)
[![npm downloads](https://img.shields.io/npm/dt/angularx-semantic-ui.svg)](https://www.npmjs.com/package/angularx-semantic-ui)
[![licence](https://img.shields.io/npm/l/angularx-semantic-ui.svg)](https://opensource.org/licenses/Apache-2.0)

AngularX Components for <a href="http://semantic-ui.com/">Semantic UI</a>
<br>
`No jQuery Dependency`

# Install
```
npm install angularx-semantic-ui --save
import { L_SEMANTIC_UI_MODULE } from 'angularx-semantic-ui';
```

# Demo 
[Online](https://lon-yang.github.io/angularx-semantic-ui-demo)

# Current Included Components
- <a href="https://github.com/lon-yang/angularx-semantic-ui/blob/master/src/checkbox">CheckBox</a>
- <a href="https://github.com/lon-yang/angularx-semantic-ui/blob/master/src/dimmer">Dimmer</a>
- <a href="https://github.com/lon-yang/angularx-semantic-ui/blob/master/src/dropdown">Dropdown</a>
- <a href="https://github.com/lon-yang/angularx-semantic-ui/blob/master/src/loader">Loader</a>
- <a href="https://github.com/lon-yang/angularx-semantic-ui/blob/master/src/progress">Progress</a>
- <a href="https://github.com/lon-yang/angularx-semantic-ui/blob/master/src/rating">Rating</a>
- <a href="https://github.com/lon-yang/angularx-semantic-ui/blob/master/src/modal">Modal</a>
- <a href="https://github.com/lon-yang/angularx-semantic-ui/blob/master/src/tab">Tab</a>
- <a href="https://github.com/lon-yang/angularx-semantic-ui/blob/master/src/accordion">Accordion</a>
- <a href="https://github.com/lon-yang/angularx-semantic-ui/blob/master/src/popup">Popup</a>
- <a href="https://github.com/lon-yang/angularx-semantic-ui/blob/master/src/pagination">Pagination</a>
- <a href="https://github.com/lon-yang/angularx-semantic-ui/blob/master/src/tags-input">Tags-Input</a>

# Change Log
- 2017-11-20 Rename 'angular2-semantic-ui' to 'angularx-semantic-ui', Support `Angular 5`

==> angularx-semantic-ui-0.0.2.tgz: package/README.md <==
# angularx-semantic-ui
[![peerDependencies Status](https://david-dm.org/lon-yang/angularx-semantic-ui/peer-status.svg)](https://david-dm.org/lon-yang/angularx-semantic-ui?type=peer)
[![npm version](https://badge.fury.io/js/angularx-semantic-ui.svg)](https://badge.fury.io/js/angularx-semantic-ui)
[![npm downloads](https://img.shields.io/npm/dt/angularx-semantic-ui.svg)](https://www.npmjs.com/package/angularx-semantic-ui)
[![licence](https://img.shields.io/npm/l/angularx-semantic-ui.svg)](https://opensource.org/licenses/Apache-2.0)

AngularX Components for <a href="http://semantic-ui.com/">Semantic UI</a>
<br>
`No jQuery Dependency`

# Install
```
npm install angularx-semantic-ui --save
import { L_SEMANTIC_UI_MODULE } from 'angularx-semantic-ui';
```

# Demo 
[Online](https://lon-yang.github.io/angularx-semantic-ui)

# Current Included Components
- <a href="https://github.com/lon-yang/angularx-semantic-ui/blob/master/src/checkbox">CheckBox</a>
- <a href="https://github.com/lon-yang/angularx-semantic-ui/blob/master/src/dimmer">Dimmer</a>
- <a href="https://github.com/lon-yang/angularx-semantic-ui/blob/master/src/dropdown">Dropdown</a>
- <a href="https://github.com/lon-yang/angularx-semantic-ui/blob/master/src/loader">Loader</a>
- <a href="https://github.com/lon-yang/angularx-semantic-ui/blob/master/src/progress">Progress</a>
- <a href="https://github.com/lon-yang/angularx-semantic-ui/blob/master/src/rating">Rating</a>
- <a href="https://github.com/lon-yang/angularx-semantic-ui/blob/master/src/modal">Modal</a>
- <a href="https://github.com/lon-yang/angularx-semantic-ui/blob/master/src/tab">Tab</a>
- <a href="https://github.com/lon-yang/angularx-semantic-ui/blob/master/src/accordion">Accordion</a>
- <a href="https://github.com/lon-yang/angularx-semantic-ui/blob/master/src/popup">Popup</a>
- <a href="https://github.com/lon-yang/angularx-semantic-ui/blob/master/src/pagination">Pagination</a>
- <a href="https://github.com/lon-yang/angularx-semantic-ui/blob/master/src/tags-input">Tags-Input</a>

# Change Log
- 2017-11-20 Rename 'angular2-semantic-ui' to 'angularx-semantic-ui', Support `Angular 5`
